@@ -140,7 +140,7 @@ std::ostream & operator << (std::ostream & o, const Compteur & c){
 }
 
 double AtomeListe::weight(fraction mult)const{
-  const AtomeListe * al;
+  // const AtomeListe * al;
   double w=0.0;
   if(Zed!=0 && Zed!=-1 ){ /* cas où ce n'est pas un groupe ou un électron */
     w=mendelweight(symb)*nb*mult.i/mult.d;
@@ -153,7 +153,7 @@ double AtomeListe::weight(fraction mult)const{
 }
 
 void AtomeListe::compte(Compteur &c, fraction mult)const{
-  const AtomeListe * al;
+  // const AtomeListe * al;
   if(Zed!=0 && Zed!=-1 ){ /* cas où ce n'est pas un groupe ou un électron */
     std::string key(symb);
     c[key] +=1.0*nb*mult.i/mult.d;
@@ -308,8 +308,11 @@ void Molec::coeff( fraction f){
 
 bool Molec::printNernst(std::ostream & o, const char * prefix){
   switch(t){
-  case sol : return 0;
+  case sol :
+  case liquid:
+    return 0;
   case aqueous :
+  case aqueous_explicit:
     if (iswater() || iselectron()) return 0;
     o << prefix << "[" << *al;
     if (ch){
@@ -334,6 +337,7 @@ bool Molec::printNernst(std::ostream & o, const char * prefix){
     }
     return 1;
   }
+  return 0;
 }
 
 bool Molec::printNernstWIMS(std::ostream & o, bool wantedlatex){
@@ -341,10 +345,13 @@ bool Molec::printNernstWIMS(std::ostream & o, bool wantedlatex){
     return false;
   }
   switch(t){
-  case sol : {
-    return false;
-  }
+  case sol :
+  case liquid :
+    {
+      return false;
+    }
   case aqueous :
+  case aqueous_explicit :
     if(wantedlatex){
       o <<  "[" << *al;
     }else{
@@ -453,7 +460,7 @@ int Membre::findMol(const Molec * m){
   // returns the index of a molecule with the same atomlist if any
   // else returns -1.
   int result=-1;
-  for(int i=0; i<size(); i++){
+  for(unsigned int i=0; i<size(); i++){
     if ((*this)[i]->eqMol(m)) result=i;
   }
   return result;
@@ -469,7 +476,7 @@ void Membre::addMol(const Molec * m){
 }
 
 void Membre::addMembre(const Membre * m){
-  for(int i=0; i<m->size(); i++){
+  for(unsigned int i=0; i<m->size(); i++){
     addMol((*m)[i]);
   }
 }
@@ -477,26 +484,26 @@ void Membre::addMembre(const Membre * m){
 void Membre::eraseNull(){
   Membre m(*this);
   clear();
-  for(int i=0; i < m.size();i++){
+  for(unsigned int i=0; i < m.size();i++){
     if (m[i]->nombre().i>0) push_back(m[i]);
   }
 }
 
 void Membre::compte(Compteur & c)const{
-  for(int i =0; i < size(); i++){
+  for(unsigned int i =0; i < size(); i++){
     operator [] (i)->compte(c);
   }
 }
 
 void Membre::numerote(){
-  for (int i=0; i < size(); i++){
+  for (unsigned int i=0; i < size(); i++){
     operator [](i)->numero(i);
     operator [](i)->liste().numerote();
   }
 }
 
 void Membre::triage(){
-  int i,j;
+  unsigned int i,j;
   for (i=0; i < size(); i++){
     operator [](i)->triage();
   }
@@ -513,46 +520,46 @@ void Membre::triage(){
 
 void Membre::printcount(std::ostream & o) const{
   bool first=true;
-  for(int i=0; i < size(); i++){
+  for(unsigned int i=0; i < size(); i++){
     first=operator[](i)->printcount(o,first);
   }
 }
 
 void Membre::printelec(std::ostream & o) const{
   bool first=true;
-  for(int i=0; i < size(); i++){
+  for(unsigned int i=0; i < size(); i++){
     first=operator[](i)->printelec(o,first);
   }
 }
 
 void Membre::printspecies(std::ostream & o) const{
   bool first=true;
-  for(int i=0; i < size(); i++){
+  for(unsigned int i=0; i < size(); i++){
     first=operator[](i)->printspecies(o,first);
   }
 }
 
 void Membre::printnorm(std::ostream & o) const{
-  for(int i=0; i < size(); i++){
+  for(unsigned int i=0; i < size(); i++){
     operator[](i)->printnorm(o);
     if (i < size()-1) o << " + ";
   }
 }
 
 void Membre::printweight(std::ostream & o) const{
-  for(int i=0; i < size(); i++){
+  for(unsigned int i=0; i < size(); i++){
     o << operator[](i)->weight();
     if (i < size()-1) o << " ";
   }
 }
 
 void Membre::coeff( fraction f){
-  for (int i=0; i<size(); i++) operator[](i)->coeff(f);
+  for (unsigned int i=0; i<size(); i++) operator[](i)->coeff(f);
 }
 
 int Membre::printableNernst(){
   int result=0;
-  for (int i=0; i<size(); i++) {
+  for (unsigned int i=0; i<size(); i++) {
     if (operator[](i)->typage() != sol && 
 	!operator[](i)->iswater() &&
 	!operator[](i)->iselectron()) result =1;
@@ -561,7 +568,7 @@ int Membre::printableNernst(){
 }
 
 bool Membre::redox()const{
-  for (int i=0; i<size(); i++){
+  for (unsigned int i=0; i<size(); i++){
     if ((*this)[i]->iselectron()) /* c'est un électron */ return 1;
   }
   return 0;
@@ -570,14 +577,14 @@ bool Membre::redox()const{
 fraction  Membre::nbelectron()const{
   fraction result(0);
 
-  for(int i = 0; i<size(); i++) result=result+(*this)[i]->nbelectron();
+  for(unsigned int i = 0; i<size(); i++) result=result+(*this)[i]->nbelectron();
   return result;
 }
 
 void Membre::printNernst(std::ostream & o){
   bool printed = 0; 
   const char * prefix="";
-  for (int i=0; i<size(); i++) {
+  for (unsigned int i=0; i<size(); i++) {
     if (i>0) prefix="\\,";
     if (operator[](i)->printNernst(o, prefix)){
       printed = 1; 
@@ -589,7 +596,7 @@ void Membre::printNernst(std::ostream & o){
 void Membre::printNernstWIMS(std::ostream & o, bool wantedlatex){
   bool printed = false; 
   bool addcomma = false;
-  for (int i=0; i<size(); i++) {
+  for (unsigned int i=0; i<size(); i++) {
     std::ostringstream w;
     if (operator[](i)->printNernstWIMS(w,wantedlatex)){
       if (addcomma) o << ", ";
@@ -604,7 +611,7 @@ void Membre::printNernstWIMS(std::ostream & o, bool wantedlatex){
 }
 
 std::ostream & operator << (std::ostream & o, const Membre & m){
-  for(int i=0; i < m.size()-1; i++){
+  for(unsigned int i=0; i < m.size()-1; i++){
     o << *m[i] << "\\,+\\,";
   }
   o << *m[m.size()-1];
